import os

from leapp.actors import Actor
from leapp.libraries.common.config import architecture
from leapp.libraries.common.rpms import has_package
from leapp.libraries.stdlib import run
from leapp.models import (
    InstalledRPM,
    RepositoriesSetupTasks,
    RpmTransactionTasks,
)
from leapp.tags import FactsPhaseTag, IPUWorkflowTag

POSTGRESQL_SCL_DATA_PATH = '/var/opt/rh/rh-postgresql12/lib/pgsql/data/'


class FixConfilictPakcages(Actor):
    """
    fix known conflict packages.
    
    whether the system has both libpq-devel and postgresql-server-devel installed, as well as either postgresql-test or postgresql-static.
    """

    name = 'fix_conflict_packages'
    consumes = (InstalledRPM, )
    produces = (RepositoriesSetupTasks, RpmTransactionTasks)
    tags = (IPUWorkflowTag, FactsPhaseTag)

    def process(self):
        to_install = []
        modules_to_enable = []
        
        has_conflict = has_package(InstalledRPM, 'libpq-devel') and has_package(InstalledRPM, 'postgresql-server-devel') and (has_package(InstalledRPM, 'postgresql-test') or has_package(InstalledRPM, 'postgresql-static'))
        
        if  has_conflict:
            to_remove = ['libpq-devel']
            self.produce(RpmTransactionTasks(
                to_remove=to_remove,
                to_install=to_install,
                modules_to_enable=modules_to_enable
                )
            )
